# Unified Cloud Storage

A simple project that provides an API to consume multiples Cloud Storage from different providers (just s3 at the moment).

## Quick Installation
TBD

## Usage
TBD

### Reference
The project was based on the [scottwernervt Cloud Storage project](https://github.com/scottwernervt/cloudstorage).
I did just for praticing purpose.